@@ -202,10 +202,10 @@ class Calendar extends \Flake\Core\Model\Db {
             "label"      => "Calendar color",
             "validation" => "color",
             "popover"    => [
-                    "title"   => "Calendar color",
-                    "content" => "This is the color that will be displayed in your CalDAV client.<br/>" .
-                    "Must be supplied in format '#RRGGBBAA' (alpha channel optional) with hexadecimal values.<br/>" .
-                    "This value is optional.",
+                "title"   => "Calendar color",
+                "content" => "This is the color that will be displayed in your CalDAV client.<br/>" .
+                "Must be supplied in format '#RRGGBBAA' (alpha channel optional) with hexadecimal values.<br/>" .
+                "This value is optional.",
             ],
         ]));
 
@@ -244,7 +244,7 @@ class Calendar extends \Flake\Core\Model\Db {
 
     function hasInstances() {
         $rSql = $GLOBALS["DB"]->exec_SELECTquery(
-            "count(*)",
+            "count(*) as count",
             "calendarinstances",
             "calendarid='" . $this->aData["calendarid"] . "'"
         );
@@ -254,7 +254,7 @@ class Calendar extends \Flake\Core\Model\Db {
         } else {
             reset($aRs);
 
-            return $aRs["count(*)"] > 1;
+            return $aRs["count"] > 1;
         }
     }
 
