@@ -28,8 +28,8 @@
 namespace Flake\Core\Datastructure;
 
 abstract class ChainLink implements \Flake\Core\Datastructure\Chainable {
-    protected $__container = null;
-    protected $__key = null;
+    protected $__container;
+    protected $__key;
 
     function chain(Chain $container, $key) {
         $this->__container = $container;
@@ -60,6 +60,7 @@ abstract class ChainLink implements \Flake\Core\Datastructure\Chainable {
         $this->__container->offsetUnset($offset);
     }
 
+    #[\ReturnTypeWillChange]
     function &offsetGet($offset) {
         if (is_null($this->__container)) {
             return null;
@@ -74,10 +75,12 @@ abstract class ChainLink implements \Flake\Core\Datastructure\Chainable {
         $this->__container->rewind();
     }
 
+    #[\ReturnTypeWillChange]
     function current() {
         return $this->__container->current();
     }
 
+    #[\ReturnTypeWillChange]
     function key() {
         return $this->__container->key();
     }
