@@ -1,4 +1,5 @@
 <?php
+
 #################################################################
 #  Copyright notice
 #
@@ -24,10 +25,13 @@
 #  This copyright notice MUST APPEAR in all copies of the script!
 #################################################################
 
-
 namespace Flake\Core;
 
 abstract class PostConnectionService extends \Flake\Core\FLObject {
+    /**
+     * @var array
+     */
+    private $aParams;
 
     function __construct($aParams = []) {
         $this->aParams = $aParams;
